@@ -39,8 +39,8 @@ import re
 from django.contrib.auth.models import User
 from django.db import models as db
 from django.utils.translation import ugettext_lazy as _
+from dj.choices import Country, Gender
 
-from lck.django.choices import Country, Gender
 from lck.django.common.templatetags.thumbnail import thumbnail
 
 TZ_CHOICES = [(float(x[0]), x[1]) for x in (
@@ -118,7 +118,7 @@ class BasicInfo(db.Model):
     def get_country_display_english(self):
         """Displays the country of origin in its English form. This is useful
         for distionary lookups."""
-        return Country.RawFromID(self.country)
+        return Country.raw_from_id(self.country)
 
     def get_profile(self):
         return self
